==> ml-git-1.2.0.tar.gz: ml-git-1.2.0/tests/integration/commands.py <==
"""
© Copyright 2020 HP Development Company, L.P.
SPDX-License-Identifier: GPL-2.0-only
"""

MLGIT_INIT = 'ml-git repository init'
MLGIT_REMOTE_ADD = 'ml-git repository remote %s add "%s"'
MLGIT_REMOTE_ADD_GLOBAL = 'ml-git repository remote %s add "%s" --global'
MLGIT_STORE_ADD = 'ml-git repository store add %s --credentials=%s'
MLGIT_STORE_ADD_WITH_ENDPOINT = 'ml-git repository store add %s --credentials=%s --endpoint-url=%s'
MLGIT_STORE_ADD_WITH_TYPE = 'ml-git repository store add %s --credentials=%s --type=%s'
MLGIT_ENTITY_INIT = 'ml-git %s init'
MLGIT_COMMIT = 'ml-git %s commit %s %s'
MLGIT_PUSH = 'ml-git %s push %s'
MLGIT_UPDATE = 'ml-git %s update'
MLGIT_REPOSITORY_UPDATE = 'ml-git repository update'
MLGIT_CHECKOUT = 'ml-git %s checkout %s'
MLGIT_ADD = 'ml-git %s add %s %s'
MLGIT_STATUS = 'ml-git %s status %s'
MLGIT_FETCH = 'ml-git %s fetch %s'
MLGIT_TAG_LIST = 'ml-git %s tag list %s'
MLGIT_RESET = 'ml-git %s reset %s'
MLGIT_REMOTE_FSCK = 'ml-git %s remote-fsck %s'
MLGIT_FSCK = 'ml-git %s fsck'
MLGIT_SHOW = 'ml-git %s show %s'
MLGIT_LIST = 'ml-git %s list'
MLGIT_BRANCH = 'ml-git %s branch %s'
MLGIT_CREATE = 'ml-git %s create %s'
MLGIT_CLONE = 'ml-git clone "%s" %s'
MLGIT_TAG_ADD = 'ml-git %s tag add %s %s'
MLGIT_IMPORT = 'ml-git %s import %s %s'
MLGIT_EXPORT = 'ml-git %s export %s'
MLGIT_UNLOCK = 'ml-git %s unlock %s %s'
MLGIT_STORE_DEL = 'ml-git repository store del %s'
MLGIT_LOG = 'ml-git %s log %s %s'
MLGIT_CONFIG = 'ml-git repository config'
MLGIT_REMOTE_DEL = 'ml-git repository remote %s del'

==> ml-git-1.4.1.tar.gz: ml-git-1.4.1/tests/integration/commands.py <==
"""
© Copyright 2020 HP Development Company, L.P.
SPDX-License-Identifier: GPL-2.0-only
"""

MLGIT_INIT = 'ml-git repository init'
MLGIT_REMOTE_ADD = 'ml-git repository remote %s add "%s"'
MLGIT_REMOTE_ADD_GLOBAL = 'ml-git repository remote %s add "%s" --global'
MLGIT_STORE_ADD = 'ml-git repository store add %s --credentials=%s'
MLGIT_STORE_ADD_WITHOUT_CREDENTIALS = 'ml-git repository store add %s'
MLGIT_STORE_ADD_WITH_ENDPOINT = 'ml-git repository store add %s --credentials=%s --endpoint-url=%s'
MLGIT_STORE_ADD_WITH_TYPE = 'ml-git repository store add %s --credentials=%s --type=%s'
MLGIT_ENTITY_INIT = 'ml-git %s init'
MLGIT_COMMIT = 'ml-git %s commit %s %s'
MLGIT_PUSH = 'ml-git %s push %s'
MLGIT_UPDATE = 'ml-git %s update'
MLGIT_REPOSITORY_UPDATE = 'ml-git repository update'
MLGIT_CHECKOUT = 'ml-git %s checkout %s'
MLGIT_ADD = 'ml-git %s add %s %s'
MLGIT_STATUS = 'ml-git %s status %s --full'
MLGIT_STATUS_DIRECTORY = 'ml-git %s status %s %s'
MLGIT_FETCH = 'ml-git %s fetch %s'
MLGIT_TAG_LIST = 'ml-git %s tag list %s'
MLGIT_RESET = 'ml-git %s reset %s'
MLGIT_REMOTE_FSCK = 'ml-git %s remote-fsck %s'
MLGIT_FSCK = 'ml-git %s fsck'
MLGIT_SHOW = 'ml-git %s show %s'
MLGIT_LIST = 'ml-git %s list'
MLGIT_BRANCH = 'ml-git %s branch %s'
MLGIT_CREATE = 'ml-git %s create %s'
MLGIT_CLONE = 'ml-git clone "%s" %s'
MLGIT_TAG_ADD = 'ml-git %s tag add %s %s'
MLGIT_IMPORT = 'ml-git %s import %s %s'
MLGIT_EXPORT = 'ml-git %s export %s'
MLGIT_UNLOCK = 'ml-git %s unlock %s %s'
MLGIT_STORE_DEL = 'ml-git repository store del %s'
MLGIT_LOG = 'ml-git %s log %s %s'
MLGIT_CONFIG = 'ml-git repository config'
MLGIT_REMOTE_DEL = 'ml-git repository remote %s del'
MLGIT_STATUS_SHORT = 'ml-git %s status %s'
MLGIT_REPOSITORY_GC = 'ml-git repository gc'
